@@ -5,15 +5,15 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.36.0")
+(defparameter *autoconf-version* "5.37.3")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/libexec")
 (defparameter *autoconf-datadir* "/usr/share")
 (defparameter *autoconf-infodir* "/usr/share/info")
-(defparameter *autoconf-host* "i686-pc-cygwin")
+(defparameter *autoconf-host* "x86_64-unknown-cygwin")
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-ld-flags* "")
  
-(defparameter *maxima-src-root* "/mnt/share/maint/maxima.x86/src/maxima-5.36.0")
-(defparameter *maxima-build-root* "/mnt/share/maint/maxima.x86/build")
+(defparameter *maxima-src-root* "/mnt/share/maint/maxima.x86_64/src/cygwin-branch-5_37-e93959a")
+(defparameter *maxima-build-root* "@expanded_top_builddir@")
 (defparameter *maxima-default-layout-autotools* "true")
